@@ -66,12 +66,16 @@ class AutoDraw:
         done: bool = False
         while not done:
             canvas = await self.client.get_canvas()
+            loop = False
             for _x, _y, pix in self.pixels:
                 x = _x + self.x
                 y = _y + self.y
                 if canvas[x, y] != pix:
                     await self.do_pixel(x, y, pix)
-                    continue
+                    loop = True
+                    break
+            if loop:
+                continue
             if not forever:
                 return
             await asyncio.sleep(guard_delay)
@@ -100,8 +104,8 @@ class AutoDraw:
             for x, p in enumerate(data[start : start + width]):
                 if image.mode == "RGBA":
                     p = list(p)
-                    c = Color(*p)
                     p[-1] = map_255_to_1(p[-1])
+                    c = Color(*p)
                     if bg_color:
                         c = Color(*bg_color.add_color_with_alpha(c))
                 else:
